@@ -7,6 +7,10 @@ module RablRails
 
         RablRails.enable_jsonp_callbacks && params.has_key?(:callback) ? "#{params[:callback]}(#{json})" : json
       end
+
+      def resolve_cache_key(key, data)
+        "#{super}.json"
+      end
     end
   end
 end
\ No newline at end of file
